;; Generated package description from jit-spell.el  -*- no-byte-compile: t -*-
(define-package "jit-spell" "0.2.0.20230319.101638" "Just-in-time spell checking" '((emacs "27.1") (compat "29.1")) :commit "2a34f68726807d17292da906be5943bbd6d2e496" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("tools" "wp") :url "https://github.com/astoff/jit-spell")
